@@ -29,7 +29,7 @@
 #include <QApplication>
 
 #include "juk.h"
-#include "config-juk.h"
+#include <config-juk.h>
 
 static const char description[] = I18N_NOOP("Jukebox and music manager by the KDE community");
 static const char scott[]       = I18N_NOOP("Author, chief dork and keeper of the funk");
@@ -111,6 +111,8 @@ int main(int argc, char *argv[])
         KNotification::event("dock_mode",i18n("JuK Docked"), message);
     }
 
+    a.setAttribute(Qt::AA_UseHighDpiPixmaps, true);
+
     return a.exec();
 }
 
